@@ -4,23 +4,20 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\Common\Collections;
 
+use Doctrine\Common\Collections\AbstractLazyCollection;
 use Doctrine\Common\Collections\ArrayCollection;
 use Doctrine\Common\Collections\Collection;
+use PHPUnit\Framework\Attributes\CoversClass;
 
 use function assert;
 
 /**
- * Tests for {@see \Doctrine\Common\Collections\AbstractLazyCollection}.
- *
- * @covers \Doctrine\Common\Collections\AbstractLazyCollection
+ * Tests for {@see AbstractLazyCollection}.
  */
+#[CoversClass(AbstractLazyCollection::class)]
 class AbstractLazyArrayCollectionTest extends ArrayCollectionTestCase
 {
-    /**
-     * @param mixed[] $elements
-     *
-     * @return Collection<mixed>
-     */
+    /** @inheritDoc */
     protected function buildCollection(array $elements = []): Collection
     {
         return new LazyArrayCollection(new ArrayCollection($elements));
