@@ -7,10 +7,11 @@ namespace Doctrine\Tests\Common\Collections;
 use Doctrine\Common\Collections\ArrayCollection;
 use Doctrine\Common\Collections\Collection;
 use Doctrine\Common\Collections\Criteria;
-use Doctrine\Common\Collections\Expr\Expression;
 use Doctrine\Common\Collections\Expr\Value;
 use Doctrine\Common\Collections\Order;
-use RuntimeException;
+use Doctrine\Deprecations\PHPUnit\VerifyDeprecations;
+use PHPUnit\Framework\Attributes\Group;
+use PHPUnit\Framework\Attributes\IgnoreDeprecations;
 use stdClass;
 
 use function count;
@@ -18,6 +19,8 @@ use function is_string;
 
 class CollectionTest extends CollectionTestCase
 {
+    use VerifyDeprecations;
+
     protected function setUp(): void
     {
         $this->collection = new ArrayCollection();
@@ -29,10 +32,19 @@ class CollectionTest extends CollectionTestCase
         self::assertTrue(is_string((string) $this->collection));
     }
 
-    /** @group DDC-1637 */
-    public function testMatching(): void
+    #[Group('DDC-1637')]
+    #[IgnoreDeprecations]
+    public function testMatchingLegacy(): void
     {
-        $this->fillMatchingFixture();
+        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/collections/pull/472');
+
+        $std1               = new stdClass();
+        $std1->foo          = 'bar';
+        $this->collection[] = $std1;
+
+        $std2               = new stdClass();
+        $std2->foo          = 'baz';
+        $this->collection[] = $std2;
 
         $col = $this->collection->matching(new Criteria(Criteria::expr()->eq('foo', 'bar')));
         self::assertInstanceOf(Collection::class, $col);
@@ -40,6 +52,17 @@ class CollectionTest extends CollectionTestCase
         self::assertEquals(1, count($col));
     }
 
+    public function testMatching(): void
+    {
+        $this->collection[] = new TestObjectPrivatePropertyOnly(42);
+        $this->collection[] = new TestObjectPrivatePropertyOnly(84);
+
+        $col = $this->collection->matching(new Criteria(Criteria::expr()->eq('fooBar', 42), firstResult: 0, accessRawFieldValues: true));
+        self::assertInstanceOf(Collection::class, $col);
+        self::assertNotSame($col, $this->collection);
+        self::assertEquals(1, count($col));
+    }
+
     public function testMatchingCallable(): void
     {
         $this->fillMatchingFixture();
@@ -48,6 +71,8 @@ class CollectionTest extends CollectionTestCase
         $col = $this->collection->matching(
             new Criteria(
                 new Value(static fn (stdClass $test): bool => $test->foo === 1),
+                firstResult: 0,
+                accessRawFieldValues: true,
             ),
         );
 
@@ -56,21 +81,28 @@ class CollectionTest extends CollectionTestCase
         self::assertEquals(1, count($col));
     }
 
-    public function testMatchingUnknownThrowException(): void
-    {
-        self::expectException(RuntimeException::class);
-        self::expectExceptionMessage('Unknown Expression GenericExpression');
-
-        $genericExpression = $this->getMockBuilder(Expression::class)
-            ->setMockClassName('GenericExpression')
-            ->getMock();
-
-        $this->collection->matching(new Criteria($genericExpression));
-    }
-
-    /** @group DDC-1637 */
+    #[Group('DDC-1637')]
     public function testMatchingOrdering(): void
     {
+        $this->collection['one']   = $obj1 = new TestObjectPrivatePropertyOnly(18);
+        $this->collection['two']   = $obj2 = new TestObjectPrivatePropertyOnly(10);
+        $this->collection['three'] = $obj3 = new TestObjectPrivatePropertyOnly(78);
+
+        $criteria = Criteria::create(true)->orderBy(['fooBar' => Order::Ascending]);
+
+        $col = $this->collection->matching($criteria);
+
+        self::assertInstanceOf(Collection::class, $col);
+        self::assertNotSame($col, $this->collection);
+        self::assertEquals(['two' => $obj2, 'one' => $obj1, 'three' => $obj3], $col->toArray());
+    }
+
+    #[Group('DDC-1637')]
+    #[IgnoreDeprecations]
+    public function testMatchingOrderingLegacy(): void
+    {
+        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/collections/pull/472');
+
         $this->fillMatchingFixture();
 
         $col = $this->collection->matching(new Criteria(null, ['foo' => Order::Descending]));
@@ -82,12 +114,12 @@ class CollectionTest extends CollectionTestCase
         self::assertEquals('bar', $col->last()->foo);
     }
 
-    /** @group DDC-1637 */
+    #[Group('DDC-1637')]
     public function testMatchingSlice(): void
     {
         $this->fillMatchingFixture();
 
-        $col = $this->collection->matching(new Criteria(null, null, 1, 1));
+        $col = $this->collection->matching(new Criteria(null, null, 1, 1, accessRawFieldValues: true));
 
         self::assertInstanceOf(Collection::class, $col);
         self::assertNotSame($col, $this->collection);
